@@ -1,5 +1,5 @@
 package Module::Build::Tiny;
-$Module::Build::Tiny::VERSION = '0.041';
+$Module::Build::Tiny::VERSION = '0.042';
 use strict;
 use warnings;
 use Exporter 5.57 'import';
@@ -61,14 +61,20 @@ sub process_xs {
 	my $version = $options->{meta}->version;
 	require ExtUtils::CBuilder;
 	my $builder = ExtUtils::CBuilder->new(config => $options->{config}->values_set);
-	my $ob_file = $builder->compile(source => $c_file, defines => { VERSION => qq/"$version"/, XS_VERSION => qq/"$version"/ }, include_dirs => [ curdir, dirname($source) ]);
+	my @objects = $builder->compile(source => $c_file, defines => { VERSION => qq/"$version"/, XS_VERSION => qq/"$version"/ }, include_dirs => [ curdir, 'include', dirname($source) ]);
+
+	my $o = $options->{config}->get('_o');
+	for my $c_source (find(qr/\.c$/, 'src')) {
+		my $o_file = catfile($tempdir, basename($c_source, '.c') . $o);
+		push @objects, $builder->compile(source => $c_file, include_dirs => [ curdir, 'include', dirname($source) ])
+	}
 
 	require DynaLoader;
 	my $mod2fname = defined &DynaLoader::mod2fname ? \&DynaLoader::mod2fname : sub { return $_[0][-1] };
 
 	mkpath($archdir, $options->{verbose}, oct '755') unless -d $archdir;
 	my $lib_file = catfile($archdir, $mod2fname->(\@parts) . '.' . $options->{config}->get('dlext'));
-	return $builder->link(objects => $ob_file, lib_file => $lib_file, module_name => join '::', @parts);
+	return $builder->link(objects => \@objects, lib_file => $lib_file, module_name => join '::', @parts);
 }
 
 sub find {
@@ -81,7 +87,7 @@ sub find {
 sub contains_pod {
 	my ($file) = @_;
 	return unless -T $file;
-	return read_file($file) =~ /^\=(?:head|pod|item)/;
+	return read_file($file) =~ /^\=(?:head|pod|item)/m;
 }
 
 my %actions = (
@@ -191,7 +197,7 @@ Module::Build::Tiny - A tiny replacement for Module::Build
 
 =head1 VERSION
 
-version 0.041
+version 0.042
 
 =head1 SYNOPSIS
 
